@@ -151,11 +151,11 @@ class Session {
  * 
  * @param $messageFunc function コールバック関数
  */
-  public function set_message_func(&$messageFunc) {
+  public function set_message_func($messageFunc) {
     if ($this->state >= 2) {
       throw new Exception (__FUNCTION__.": Main content is already sent.");
     }
-    $this->messageFunc =& $messageFunc;
+    $this->messageFunc = $messageFunc;
   }
 
 /**
@@ -166,11 +166,11 @@ class Session {
  * 
  * @param $progressFunc function コールバック関数
  */
-  function set_progress_func(&$progressFunc) {
+  function set_progress_func($progressFunc) {
     if ($this->state >= 2) {
       throw new Exception(__FUNCTION__.": Main content is already sent.");
     }
-    $this->progressFunc =& $progressFunc;
+    $this->progressFunc = $progressFunc;
   }
 
 /**
@@ -179,15 +179,30 @@ class Session {
  * transcodeおよびstart_mainの前に呼び出してください。
  * コールバック関数の引数は、全体のバイト数(string)、リソース出力クラス(ResourceOutput)です。
  * 
- * @param $progressFunc function コールバック関数
+ * @param $resolverFunc function コールバック関数
  */
-  function set_resolver_func(&$resolverFunc) {
+  function set_resolver_func($resolverFunc) {
     if ($this->state >= 2) {
       throw new Exception(__FUNCTION__.": Main content is already sent.");
     }
-    $this->resolverFunc =& $resolverFunc;
+    $this->resolverFunc = $resolverFunc;
     cti_ctip_req_client_resource($this->fp, $resolverFunc ? 1 : 0);
   }
+
+/**
+ * 複数の結果を結合するモードを切り替えます。
+ * モードが有効な場合、join()の呼び出しで複数の結果を結合して返します。
+ *
+ * transcodeおよびstart_mainの前に呼び出してください。
+ * 
+ * @param $continuous function 有効にするにはTRUE
+ */
+  function set_continuous($continuous) {
+    if ($this->state >= 2) {
+      throw new Exception(__FUNCTION__.": Main content is already sent.");
+    }
+    cti_ctip_req_continuous($this->fp, $continuous ? 1 : 0);
+  }
   
 /**
  * プロパティを設定します。
@@ -384,6 +399,19 @@ class Session {
     $this->results = new SingleResult(new StreamBuilder());
     $this->state = 1;
   }
+    
+/**
+ * 結果を結合します。
+ */
+  public function join() {
+    if ($this->state >= 3) {
+      throw new Exception(__FUNCTION__.": The session is already closed.");
+    }
+    cti_ctip_req_join($this->fp);
+    $this->state = 2;
+    while ($this->_build_next())
+      ; 
+  }
   
 /**
  * セッションを閉じます。
@@ -490,6 +518,8 @@ class Session {
       unset($this->builder);
       $this->mainLength = null;
       $this->mainRead = null;
+      
+      case CTI_CTIP_RES_NEXT:
       $this->state = 1;
       return false;
     }
